/*
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.inteligr8.alfresco.activiti;

import java.util.Arrays;
import java.util.UUID;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.EnabledIf;

import com.inteligr8.alfresco.activiti.model.AppVersion;
import com.inteligr8.alfresco.activiti.model.CreateProcessInstance;
import com.inteligr8.alfresco.activiti.model.ProcessInstance;
import com.inteligr8.alfresco.activiti.model.User;
import com.inteligr8.alfresco.activiti.model.Variable;

public abstract class ConnectionClientIT extends ConditionalIT {
	
	public abstract ApsPublicRestApi getApi();
	
	@Test
	@EnabledIf("hostExists")
	public void testAppVersion() {
		AppVersion obj = this.getApi().getAppVersionApi().get();
		
		Assertions.assertNotNull(obj);
		Assertions.assertEquals("1", obj.getMajorVersion());
		Assertions.assertEquals("bpmSuite", obj.getType());
	}
	
	@Test
	@EnabledIf("hostExists")
	public void testProfile() {
		User obj = this.getApi().getProfileApi().get();
		
		Assertions.assertNotNull(obj);
		Assertions.assertEquals("admin@app.activiti.com", obj.getEmail());
	}
	
	@Test
	@EnabledIf("hostExists")
	public void testStartProcess() {
		CreateProcessInstance request = new CreateProcessInstance();
		request.setProcessDefinitionKey("qcDocument");
		request.setVariables(Arrays.asList(new Variable("acsNodeId", null, null, UUID.randomUUID().toString())));
		
		ProcessInstance response = this.getApi().getProcessInstancesApi().create(request);
		
		Assertions.assertNotNull(response);
		Assertions.assertNotNull(response.getId());
		Assertions.assertNotNull(response.getId().length() > 0);
		Assertions.assertEquals("qcDocument", response.getProcessDefinitionKey());
	}

}
